@@ -27,25 +27,8 @@ class TransportRegistry(dict):
         
         if self:
             for transport_name, transport_obj in self.items():
-                # Check if transport is set up using cache if available
-                if hasattr(self, '_setup_cache') and hasattr(self, '_email') and hasattr(self, '_platform'):
-                    # Get credentials path if available
-                    credentials_path = None
-                    if hasattr(self, '_credentials_path'):
-                        credentials_path = self._credentials_path
-                    
-                    # Check cache first
-                    if self._setup_cache.is_transport_setup_cached(
-                        self._email, 
-                        self._platform, 
-                        transport_name,
-                        credentials_path
-                    ):
-                        status = "[green]✓[/green]"
-                    else:
-                        status = "[dim]○[/dim]"
-                elif hasattr(transport_obj, 'is_setup') and transport_obj.is_setup():
-                    # Fallback to direct check
+                # Check if transport is set up
+                if hasattr(transport_obj, 'is_setup') and transport_obj.is_setup():
                     status = "[green]✓[/green]"
                 else:
                     status = "[dim]○[/dim]"
@@ -257,52 +240,124 @@ class BasePlatformClient(ABC):
         
         # Create a string buffer to capture the rich output
         string_buffer = StringIO()
-        console = Console(file=string_buffer, force_terminal=True, width=70)
+        console = Console(file=string_buffer, force_terminal=True, width=100)
         
         # Create main table
         main_table = Table(show_header=False, show_edge=False, box=None, padding=0)
-        main_table.add_column(style="dim")
+        main_table.add_column("", no_wrap=False)
         
-        # Get transports and their status with details
+        # Add project info if available
+        project_info = ""
+        if self.platform in ['google_personal', 'google_org']:
+            # For Google Org, check if project_id is already loaded
+            if self.platform == 'google_org' and hasattr(self, 'project_id') and self.project_id:
+                project_info = f" [dim](project: {self.project_id})[/dim]"
+            else:
+                # Try to get from credentials.json
+                try:
+                    creds_path = None
+                    if hasattr(self, 'find_oauth_credentials'):
+                        creds_path = self.find_oauth_credentials()
+                    elif hasattr(self, 'credentials_path'):
+                        creds_path = self.credentials_path
+                    
+                    if creds_path and creds_path.exists():
+                        import json
+                        with open(creds_path, 'r') as f:
+                            creds_data = json.load(f)
+                            if 'installed' in creds_data:
+                                project_id = creds_data['installed'].get('project_id')
+                                if project_id:
+                                    project_info = f" [dim](project: {project_id})[/dim]"
+                except:
+                    pass
+        
+        # Don't show platform header - it's redundant when viewing the platform directly
+        
+        # Get transports and their status
         if self.get_transport_layers():
-            # Create a table for transports
-            transport_table = Table(show_header=False, show_edge=False, box=None, padding=(0, 1))
-            transport_table.add_column("Transport", style="bold")
-            transport_table.add_column("Status", width=8)
-            transport_table.add_column("Setup", width=12)
-            transport_table.add_column("Features", style="dim")
-            
             for transport_name in self.get_transport_layers():
+                # Initialize status indicators
+                api_status = "[red]✗[/red]"  # Default to not enabled
+                auth_status = "[dim]✗[/dim]"  # Not authenticated by default
+                transport_style = "dim"
+                message = ""
+                
                 # Try to get transport as attribute first
                 transport_obj = getattr(self, transport_name, None)
                 if transport_obj is None and hasattr(self, 'transports'):
                     # Fallback to transports dict
                     transport_obj = self.transports.get(transport_name)
                 
-                # Status and get complexity
-                if transport_obj and hasattr(transport_obj, 'is_setup') and transport_obj.is_setup():
-                    status = "[green]✓[/green]"
-                    # Get complexity even when ready
-                    if hasattr(transport_obj, 'login_complexity'):
-                        steps = transport_obj.login_complexity
-                        setup_str = f"[green]{steps} steps[/green]"
-                    else:
-                        setup_str = "[green]Ready[/green]"
-                else:
-                    status = "[dim]○[/dim]"
-                    # Get complexity
-                    if transport_obj and hasattr(transport_obj, 'login_complexity'):
-                        steps = transport_obj.login_complexity
-                        if steps == 0:
-                            setup_str = "[yellow]0 steps[/yellow]"
-                        elif steps == 1:
-                            setup_str = "[yellow]1 step[/yellow]"
-                        else:
-                            setup_str = f"[red]{steps} steps[/red]"
-                    else:
-                        setup_str = "[dim]Unknown[/dim]"
+                # Check if transport is actually initialized and setup
+                transport_initialized = False
+                if transport_obj:
+                    # Check if this is an initialized transport (not a stub)
+                    if hasattr(transport_obj, '_setup_called') and transport_obj._setup_called:
+                        transport_initialized = True
+                        auth_status = "[green]✓[/green]"
+                    elif hasattr(transport_obj, 'is_setup') and callable(transport_obj.is_setup):
+                        # For fully initialized transports, check is_setup
+                        try:
+                            if transport_obj.is_setup():
+                                transport_initialized = True
+                                auth_status = "[green]✓[/green]"
+                        except:
+                            pass
                 
-                # Get key features
+                # Use static method to check API status
+                transport_map = None
+                if self.platform == 'google_personal':
+                    # Import the transport classes to use their static methods
+                    transport_map = {
+                        'gmail': 'syft_client.platforms.google_personal.gmail.GmailTransport',
+                        'gdrive_files': 'syft_client.platforms.google_personal.gdrive_files.GDriveFilesTransport',
+                        'gsheets': 'syft_client.platforms.google_personal.gsheets.GSheetsTransport',
+                        'gforms': 'syft_client.platforms.google_personal.gforms.GFormsTransport'
+                    }
+                elif self.platform == 'google_org':
+                    # Import the transport classes to use their static methods
+                    transport_map = {
+                        'gmail': 'syft_client.platforms.google_org.gmail.GmailTransport',
+                        'gdrive_files': 'syft_client.platforms.google_org.gdrive_files.GDriveFilesTransport',
+                        'gsheets': 'syft_client.platforms.google_org.gsheets.GSheetsTransport',
+                        'gforms': 'syft_client.platforms.google_org.gforms.GFormsTransport'
+                    }
+                    
+                if transport_map and transport_name in transport_map:
+                        try:
+                            # Import the transport class
+                            module_path, class_name = transport_map[transport_name].rsplit('.', 1)
+                            module = __import__(module_path, fromlist=[class_name])
+                            transport_class = getattr(module, class_name)
+                            
+                            # Call static method to check API
+                            if transport_class.check_api_enabled(self):
+                                api_status = "[green]✓[/green]"
+                                transport_style = "green"
+                            else:
+                                api_status = "[red]✗[/red]"
+                                transport_style = "dim"
+                                # If API is disabled, show enable message
+                                message = f" [dim](call .{transport_name}.enable_api())[/dim]"
+                        except Exception as e:
+                            # If check fails, see if it's an API disabled error
+                            if "has not been used in project" in str(e) and "before or it is disabled" in str(e):
+                                api_status = "[red]✗[/red]"
+                                message = f" [dim](call .{transport_name}.enable_api())[/dim]"
+                
+                # Set message based on transport initialization status
+                if not transport_initialized:
+                    # Transport is not initialized
+                    if api_status == "[green]✓[/green]":
+                        # API is enabled but transport not initialized
+                        message = " [dim](call .init() to initialize)[/dim]" if message == "" else message
+                    else:
+                        # API is disabled and transport not initialized
+                        if message == "":
+                            message = " [dim](not initialized)[/dim]"
+                
+                # Get key features for additional info
                 features = []
                 if transport_obj:
                     if getattr(transport_obj, 'is_keystore', False):
@@ -314,20 +369,32 @@ class BasePlatformClient(ABC):
                     if getattr(transport_obj, 'is_html_compatible', False):
                         features.append("HTML")
                 
-                feature_str = ", ".join(features) if features else "basic transport"
+                # Build feature string for display
+                feature_str = ", ".join(features) if features else ""
                 
-                transport_table.add_row(f".{transport_name}", status, setup_str, feature_str)
-            
-            main_table.add_row(transport_table)
+                # Add transport row with dual status
+                transport_row = f"  {api_status} {auth_status} [{transport_style}].{transport_name}[/{transport_style}]{message}"
+                if feature_str:
+                    transport_row += f" [dim]({feature_str})[/dim]"
+                main_table.add_row(transport_row)
         else:
             main_table.add_row("  No transport layers available")
         
         # Create the panel with the table
+        # Include project info in title if available
+        title = f"{self.__class__.__name__}(email='{self.email}')"
+        if project_info:
+            # Extract just the project ID from the formatted string
+            import re
+            match = re.search(r'project: ([^)]+)', project_info)
+            if match:
+                title = f"{self.__class__.__name__}(email='{self.email}', project='{match.group(1)}')"
+        
         panel = Panel(
             main_table,
-            title=f"{self.__class__.__name__}(email='{self.email}')",
+            title=title,
             expand=False,
-            width=70,
+            width=100,
             padding=(1, 2)
         )
         
