@@ -878,11 +878,4 @@ def verify_email_smtp(email: str) -> Dict[str, Any]:
         'smtp_data': smtp_data
     }
     
-    return result
-
-
-def get_all_platforms() -> List[Platform]:
-    """Get all available platforms (primary and secondary)"""
-    all_platforms = list(PlatformProperties.PRIMARY_PLATFORMS) + list(PlatformProperties.SECONDARY_PLATFORMS)
-    # Sort by name for consistent ordering
-    return sorted(all_platforms, key=lambda p: p.value)
+    return result
\ No newline at end of file
