@@ -47,6 +47,77 @@ class GFormsTransport(BaseTransportLayer):
         # 2. Create a form resource
         return 2  # Two additional steps
     
+    @staticmethod
+    def check_api_enabled(platform_client: Any) -> bool:
+        """
+        Check if Google Forms API is enabled.
+        
+        Args:
+            platform_client: The platform client with credentials
+            
+        Returns:
+            bool: True if API is enabled, False otherwise
+        """
+        # Check if we're in Colab environment
+        if hasattr(platform_client, 'current_environment'):
+            from ...environment import Environment
+            if platform_client.current_environment == Environment.COLAB:
+                # Forms doesn't work properly in Colab for Google Personal accounts
+                # Colab's auth doesn't provide the necessary Forms scopes
+                return False
+        
+        try:
+            
+            # Regular OAuth credential check
+            if not hasattr(platform_client, 'credentials') or not platform_client.credentials:
+                return False
+            
+            # Try to build service and make a simple API call
+            from googleapiclient.discovery import build
+            from google.auth.transport.requests import Request
+            
+            # Refresh credentials if needed
+            if platform_client.credentials.expired and platform_client.credentials.refresh_token:
+                platform_client.credentials.refresh(Request())
+            
+            # Test Forms API directly
+            forms_service = build('forms', 'v1', credentials=platform_client.credentials)
+            
+            # Try to get a non-existent form - will return 404 if API is enabled
+            try:
+                forms_service.forms().get(formId='test123').execute()
+                # If we get here, somehow the test form exists (unlikely)
+                return True
+            except Exception as e:
+                # Check if it's a 404 error (form not found = API is working)
+                if "404" in str(e) or "not found" in str(e).lower():
+                    return True
+                else:
+                    # API is disabled or other error
+                    return False
+        except Exception:
+            return False
+    
+    @staticmethod
+    def enable_api_static(transport_name: str, email: str) -> None:
+        """Show instructions for enabling Google Forms API"""
+        print(f"\n🔧 To enable the Google Forms API:")
+        print(f"\n1. Open this URL in your browser:")
+        print(f"   https://console.cloud.google.com/marketplace/product/google/forms.googleapis.com?authuser={email}")
+        print(f"\n2. Click the 'Enable' button")
+        print(f"\n3. Wait for the API to be enabled (may take 5-10 seconds)")
+        print(f"\n📝 Note: API tends to flicker for 5-10 seconds before enabling/disabling")
+    
+    @staticmethod
+    def disable_api_static(transport_name: str, email: str) -> None:
+        """Show instructions for disabling Google Forms API"""
+        print(f"\n🔧 To disable the Google Forms API:")
+        print(f"\n1. Open this URL in your browser:")
+        print(f"   https://console.cloud.google.com/apis/api/forms.googleapis.com/overview?authuser={email}")
+        print(f"\n2. Click 'Manage' or 'Disable API'")
+        print(f"\n3. Confirm by clicking 'Disable'")
+        print(f"\n📝 Note: API tends to flicker for 5-10 seconds before enabling/disabling")
+    
     def setup(self, credentials: Optional[Dict[str, Any]] = None) -> bool:
         """Setup Forms transport with OAuth2 credentials or Colab auth"""
         try:
@@ -89,22 +160,24 @@ class GFormsTransport(BaseTransportLayer):
             return False
     
     def is_setup(self) -> bool:
-        """Check if Forms transport is ready"""
-        # First check if we're cached as setup
-        if self.is_cached_as_setup():
-            return True
-            
-        # In Colab, we can always set up on demand
-        if self.environment == Environment.COLAB:
-            # Check if Colab auth is available
-            try:
-                from google.colab import auth as colab_auth
-                return True  # Can authenticate on demand
-            except ImportError:
-                pass
+        """Check if Forms transport is ready - NO CACHING, makes real API call"""
+        if not self.forms_service:
+            return False
         
-        # Otherwise check normal setup
-        return self.forms_service is not None
+        # In Colab, Forms doesn't work properly so just return False
+        if self.environment == Environment.COLAB:
+            return False
+            
+        try:
+            # Try to get a non-existent form (expecting 404 if API works)
+            self.forms_service.forms().get(formId='test123').execute()
+            return False  # Should never reach here
+        except Exception as e:
+            # If it's "not found", the API is working
+            if "not found" in str(e).lower() or "404" in str(e):
+                return True
+            else:
+                return False
     
     def send(self, recipient: str, data: Any, subject: str = "Syft Form") -> bool:
         """Create a Google Form for data collection"""
