@@ -10,12 +10,14 @@ from email.mime.multipart import MIMEMultipart
 from email.mime.base import MIMEBase
 from email import encoders
 import json
+import logging
 
 from googleapiclient.discovery import build
 from ..transport_base import BaseTransportLayer
+from ...transports.base import BaseTransport
 
 
-class GmailTransport(BaseTransportLayer):
+class GmailTransport(BaseTransportLayer, BaseTransport):
     """Gmail transport layer using Gmail API via OAuth2"""
     
     # STATIC Attributes
@@ -52,6 +54,71 @@ class GmailTransport(BaseTransportLayer):
             return 0
         return 0
     
+    @staticmethod
+    def check_api_enabled(platform_client: Any) -> bool:
+        """
+        Check if Gmail API is enabled.
+        
+        Args:
+            platform_client: The platform client with credentials
+            
+        Returns:
+            bool: True if API is enabled, False otherwise
+        """
+        # Suppress googleapiclient warnings during API check
+        googleapi_logger = logging.getLogger('googleapiclient.http')
+        original_level = googleapi_logger.level
+        googleapi_logger.setLevel(logging.ERROR)
+        
+        try:
+            # Check if we're in Colab environment
+            if hasattr(platform_client, 'current_environment'):
+                from ...environment import Environment
+                if platform_client.current_environment == Environment.COLAB:
+                    # Gmail doesn't work in Colab for Google Personal accounts
+                    # Colab's auth doesn't provide the necessary Gmail scopes
+                    return False
+            
+            # Regular OAuth credential check
+            if not hasattr(platform_client, 'credentials') or not platform_client.credentials:
+                return False
+            
+            # Try to build service and make a simple API call
+            from googleapiclient.discovery import build
+            from google.auth.transport.requests import Request
+            
+            # Refresh credentials if needed
+            if platform_client.credentials.expired and platform_client.credentials.refresh_token:
+                platform_client.credentials.refresh(Request())
+            
+            service = build('gmail', 'v1', credentials=platform_client.credentials)
+            service.users().messages().list(userId='me', maxResults=1).execute()
+            return True
+        except Exception:
+            return False
+        finally:
+            googleapi_logger.setLevel(original_level)
+    
+    @staticmethod
+    def enable_api_static(transport_name: str, email: str) -> None:
+        """Show instructions for enabling Gmail API"""
+        print(f"\n🔧 To enable the Gmail API:")
+        print(f"\n1. Open this URL in your browser:")
+        print(f"   https://console.cloud.google.com/marketplace/product/google/gmail.googleapis.com?authuser={email}")
+        print(f"\n2. Click the 'Enable' button")
+        print(f"\n3. Wait for the API to be enabled (may take 5-10 seconds)")
+        print(f"\n📝 Note: API tends to flicker for 5-10 seconds before enabling/disabling")
+    
+    @staticmethod
+    def disable_api_static(transport_name: str, email: str) -> None:
+        """Show instructions for disabling Gmail API"""
+        print(f"\n🔧 To disable the Gmail API:")
+        print(f"\n1. Open this URL in your browser:")
+        print(f"   https://console.cloud.google.com/apis/api/gmail.googleapis.com/overview?authuser={email}")
+        print(f"\n2. Click 'Manage' or 'Disable API'")
+        print(f"\n3. Confirm by clicking 'Disable'")
+        print(f"\n📝 Note: API tends to flicker for 5-10 seconds before enabling/disabling")
+    
     def setup(self, credentials: Optional[Dict[str, Any]] = None) -> bool:
         """Setup Gmail transport with OAuth2 credentials"""
         if not credentials or 'credentials' not in credentials:
@@ -72,24 +139,16 @@ class GmailTransport(BaseTransportLayer):
             return False
     
     def is_setup(self) -> bool:
-        """Check if Gmail transport is ready"""
-        # First check if we're cached as setup
-        if self.is_cached_as_setup():
-            return True
-            
-        # Otherwise check normal setup
+        """Check if Gmail transport is ready - NO CACHING, makes real API call"""
         if not self.gmail_service:
             return False
         
-        if self._setup_verified:
+        try:
+            # Simple API call - just list 1 message
+            self.gmail_service.users().messages().list(userId='me', maxResults=1).execute()
             return True
-        
-        # Test by sending email to self
-        if self._test_email_to_self():
-            self._setup_verified = True
-            return True
-            
-        return False
+        except Exception:
+            return False
     
     def _setup_gmail(self) -> None:
         """Setup Gmail labels and filters for backend emails"""
@@ -244,7 +303,29 @@ class GmailTransport(BaseTransportLayer):
             return True
             
         except Exception as e:
-            print(f"Error sending email: {e}")
+            # Only print error if not in a repr/display context
+            import sys
+            import traceback
+            
+            # Check if we're being called from __repr__ by looking at the call stack
+            stack = traceback.extract_stack()
+            in_repr = any('__repr__' in frame.name for frame in stack)
+            
+            # Check if it's an API not enabled error
+            if "has not been used in project" in str(e) and "before or it is disabled" in str(e):
+                if not in_repr:
+                    print(f"\n⚠️  Gmail API is not enabled for your project!")
+                    print("To fix this:")
+                    # Extract the URL from the error message
+                    import re
+                    url_match = re.search(r'https://[^\s]+', str(e))
+                    if url_match:
+                        print(f"1. Open: {url_match.group(0)}")
+                    print("2. Click 'ENABLE'")
+                    print("3. Wait a few minutes for the change to propagate")
+                    print("4. Try again\n")
+            elif not in_repr:
+                print(f"Error sending email: {e}")
             return False
     
     def receive(self, folder: Optional[str] = None, limit: int = 10, 
@@ -458,7 +539,7 @@ class GmailTransport(BaseTransportLayer):
                 
                 print(f"✅ Gmail test successful! Email sent to {self.email}")
                 if cleanup:
-                    print("   Email has been deleted as requested")
+                    print("   Email has been deleted as requested (re-run test(cleanup=False) to see the email yourself.)")
                 
                 return {"success": True, "url": url}
             else:
@@ -467,4 +548,118 @@ class GmailTransport(BaseTransportLayer):
                 
         except Exception as e:
             print(f"❌ Gmail test failed: {e}")
-            return {"success": False, "error": str(e)}
\ No newline at end of file
+            return {"success": False, "error": str(e)}
+    
+    # BaseTransport interface implementation
+    def add_peer(self, email: str, verbose: bool = True) -> bool:
+        """
+        Add a peer for Gmail transport
+        
+        For Gmail, this is always successful since we can send emails to any valid address.
+        We just validate the email format.
+        """
+        # Validate email format
+        if not email or '@' not in email or '.' not in email.split('@')[1]:
+            if verbose:
+                print(f"❌ Invalid email address: {email}")
+            return False
+        
+        # Gmail doesn't require any setup to send to a contact
+        if verbose:
+            print(f"✅ Peer {email} added for Gmail transport (no setup required)")
+        return True
+    
+    def remove_peer(self, email: str, verbose: bool = True) -> bool:
+        """
+        Remove a peer from Gmail transport
+        
+        For Gmail, this always succeeds since there's no persistent connection.
+        """
+        if verbose:
+            print(f"✅ Peer {email} removed from Gmail transport")
+        return True
+    
+    def list_peers(self) -> List[str]:
+        """
+        List contacts for Gmail transport
+        
+        Gmail doesn't maintain a separate peer list for transport purposes.
+        Returns empty list.
+        """
+        return []
+    
+    def _send_archive_via_transport(self, archive_data: bytes, filename: str, 
+                                   recipient: str, message_id: Optional[str] = None) -> bool:
+        """
+        Send archive data via Gmail as an email attachment
+        """
+        try:
+            # Create email message
+            msg = MIMEMultipart()
+            msg['To'] = recipient
+            msg['From'] = self.email
+            msg['Subject'] = f"{self.BACKEND_PREFIX} Syft Message" + (f" [{message_id}]" if message_id else "")
+            
+            # Add body
+            body = f"This is a Syft message containing encrypted data.\nMessage ID: {message_id or 'N/A'}"
+            msg.attach(MIMEText(body, 'plain'))
+            
+            # Attach the archive data
+            part = MIMEBase('application', 'octet-stream')
+            part.set_payload(archive_data)
+            encoders.encode_base64(part)
+            part.add_header(
+                'Content-Disposition',
+                f'attachment; filename={filename}'
+            )
+            msg.attach(part)
+            
+            # Send the email
+            raw_msg = base64.urlsafe_b64encode(msg.as_bytes()).decode()
+            message_body = {'raw': raw_msg}
+            
+            if self._labels and self.BACKEND_LABEL in self._labels:
+                message_body['labelIds'] = [self._labels[self.BACKEND_LABEL]]
+            
+            result = self.gmail_service.users().messages().send(
+                userId='me',
+                body=message_body
+            ).execute()
+            
+            return bool(result.get('id'))
+            
+        except Exception as e:
+            print(f"❌ Failed to send via Gmail: {e}")
+            return False
+    
+    @property
+    def transport_name(self) -> str:
+        """Get the name of this transport"""
+        return "gmail"
+    
+    def is_available(self) -> bool:
+        """Check if Gmail transport is available"""
+        return self.is_setup()
+    
+    def get_peer_resource(self, email: str) -> Optional[Any]:
+        """
+        Get the resource associated with a peer for Gmail
+        
+        Gmail doesn't have persistent folders/resources like Drive,
+        so we return basic availability info
+        
+        Args:
+            email: Email address of the contact
+            
+        Returns:
+            PeerResource with email info
+        """
+        from ...sync.peer_resource import PeerResource
+        
+        return PeerResource(
+            peer_email=email,
+            transport_name=self.transport_name,
+            platform_name=getattr(self._platform_client, 'platform', 'google_personal') if hasattr(self, '_platform_client') else 'google_personal',
+            resource_type='email',
+            available=self.is_setup()
+        )
\ No newline at end of file
